Struct network::noise::stream::NoiseStream [−][src]
pub struct NoiseStream<TSocket> { /* fields omitted */ }Expand description
A Noise stream with a remote peer.
Encrypts data to be written to and decrypts data that is read from the underlying socket using the noise protocol. This is done by prefixing noise payloads with a u16 (big endian) length field.
Implementations
Create a NoiseStream from a socket and a noise post-handshake session
Pull out the static public key of the remote